/*
** Copyright (c) 2004 CA.  All rights reserved.  
** This software may not be duplicated, disclosed or reproduced in whole or 
** in part for any purpose except as authorized by the applicable license agreement, 
** without the express written authorization of CA. All authorized reproductions 
** must be marked with this language.  
**
** TO THE EXTENT PERMITTED BY APPLICABLE LAW, CA PROVIDES THIS 
** SOFTWARE "AS IS" WITHOUT WARRANTY OF ANY KIND, INCLUDING 
** WITHOUT LIMITATION, ANY IMPLIED WARRANTIES OF MERCHANTABILITY, 
** FITNESS FOR A PARTICULAR PURPOSE OR NONINFRINGEMENT.  IN NO EVENT 
** WILL CA BE LIABLE TO THE END USER OR ANY THIRD PARTY FOR ANY LOSS 
** OR DAMAGE, DIRECT OR INDIRECT, FROM THE USE OF THIS MATERIAL, 
** INCLUDING WITHOUT LIMITATION, LOST PROFITS, BUSINESS 
** INTERRUPTION, GOODWILL, OR LOST DATA, EVEN IF CA IS EXPRESSLY 
** ADVISED OF SUCH LOSS OR DAMAGE.
*/
// SiteMinder Java Authorization API sample Active Response.



import com.netegrity.policyserver.smapi.*;


/**
 * ActiveResponseSample
 *
 * This Active Response will return the common name(cn) of the user if the user belongs to
 * the organizational unit specified in the invoke method's String parameter param.
 *
 * For example, put this in the Active Response field:
 *
 *   <@ lib="smjavaapi" func="JavaActiveExpression" param="com.netegrity.sdk.javaazapi.ActiveResponseSample Human Resources" @>
 *
 * and "Human Resources" will be passed as the value for param to the invoke method
 * of the com.netegrity.sdk.javaazapi.ActiveResponseSample class.
 */

public class ReadAppSpecificContextVar
    implements ActiveExpression
{
    /**
     * SiteMinder calls init() once to initialize this class before making
     * calls to invoke()
     *
     * @param context    the context to access Siteminder APIs
     * @return   0 if initialization succeeded, -1 if there was an error
     */

    public int
    init(APIContext context)
        throws Exception
    {
        // This example needs no initialization so just return "success"
        return 0;
    }


    /**
     * SiteMinder calls this function to evaluate the Active Response.
     *
     * This method will return the username if the user belongs to
     * the organizational unit specified in the parameter param.
     *
     * @param context   provides access to the Siteminder API contexts
     * @param param     an organizational unit name
     * @return          (1) if the app specific data is not set:
     *                  returns the username if the user's organizational unit[s] include
     *                  the one passed as param, otherwise null and an explanatory message will
     *                  be returned via the context's setErrorText method.
     *                  (2) if the app specific data is set:
     *                  returns the app specific data.
     * @exception       throws IllegalArgumentException if receives a null context
     *
     */

    public String
    invoke(ActiveExpressionContext context,
           String param)
        throws Exception
    {
        if (context == null)
        {
           // should never happen
           throw new IllegalArgumentException("ActiveResponseSample invoked without context");
        }

        // the User Context is required to use the methods like getProp, setProp..
        UserContext theUserContext = context.getUserContext();

        if (theUserContext == null)
        {
            context.setErrorText("No User Context.");
            return null;
        }

        return "YES";
        	
//        // Check if the app specific data is set
//        try
//        {
//            APIContext apiContext = context.getAPIContext();
//            AppSpecificContext appContext = apiContext.getAppSpecificContext();
//            byte[] data = appContext.getData();
//            if (data != null)
//            {
//                logInPSTrace(apiContext, "Context Data : " + new String(data));
//                return  new String(data);
//            }
//        }
//        catch (NullPointerException exc)
//        {
//            context.setErrorText("Failed to modify application specific context");
//        }
//        return null;
    }


    /**
     * SiteMinder calls release() once when it is shutting down so this class can
     * perform its own rundown porcedure
     *
     * @param context    the context to access Siteminder APIs
     * @return   0 if shutdown succeeded, -1 if there was an error
     */

    public int
    release(APIContext context)
        throws Exception
    {
        // This example needs no shutdown so just return "success"
        return 0;
    }
    
    void logInPSTrace(APIContext apiContext, String msg) {
   	// Log message into Policy Server Trace Log
	apiContext.trace(this.getClass().getSimpleName(),
   		this.getClass().getSimpleName()+":: ['" + msg + "']");
       }
}

// end of file ActiveResponseSample.java
